ParseExtend

Trait ParseExtend 

pub trait ParseExtend {
    type Fixed;
    type Error;

    // Required method
    fn from_buf_fixed<T: Buf>(
        buf: &mut T,
        fixed: Self::Fixed,
    ) -> Result<Self, (Self::Error, Self::Fixed)>
       where Self: Sized;
}

Required Associated Types

Required Methods

fn from_buf_fixed<T: Buf>( buf: &mut T, fixed: Self::Fixed, ) -> Result<Self, (Self::Error, Self::Fixed)>
where Self: Sized,

parsing this Type from a buf and a fixed part, returning either the Type or an Error. implementations must not modify the buf in case of an error and return the fixed

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors